@@ -3,9 +3,9 @@ package Sah::Schema::dirname::unix;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-08-11'; # DATE
+our $DATE = '2023-08-14'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.017'; # VERSION
+our $VERSION = '0.018'; # VERSION
 
 our $schema = ["str" => {
     summary => 'Filesystem directory name on a Unix system',
@@ -42,7 +42,7 @@ Sah::Schema::dirname::unix - Filesystem directory name on a Unix system
 
 =head1 VERSION
 
-This document describes version 0.017 of Sah::Schema::dirname::unix (from Perl distribution Sah-Schemas-Path), released on 2023-08-11.
+This document describes version 0.018 of Sah::Schema::dirname::unix (from Perl distribution Sah-Schemas-Path), released on 2023-08-14.
 
 =head1 SYNOPSIS
 
@@ -76,7 +76,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "foo/bar";
+ $data = "foo//bar";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
@@ -91,7 +91,7 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "foo/bar";
+ $data = "foo//bar";
  my $res = $validator->($data); # => ["","foo/bar"]
  
  # a sample invalid data
