@@ -3,9 +3,9 @@ package Sah::Schema::filename;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-08-11'; # DATE
+our $DATE = '2023-08-14'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.017'; # VERSION
+our $VERSION = '0.018'; # VERSION
 
 our $schema = [str => {
     summary => 'Filesystem file name',
@@ -59,7 +59,7 @@ Sah::Schema::filename - Filesystem file name
 
 =head1 VERSION
 
-This document describes version 0.017 of Sah::Schema::filename (from Perl distribution Sah-Schemas-Path), released on 2023-08-11.
+This document describes version 0.018 of Sah::Schema::filename (from Perl distribution Sah-Schemas-Path), released on 2023-08-14.
 
 =head1 SYNOPSIS
 
@@ -87,7 +87,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "foo";
+ $data = "foo/bar";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
@@ -102,8 +102,8 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "foo";
- my $res = $validator->($data); # => ["","foo"]
+ $data = "foo/bar";
+ my $res = $validator->($data); # => ["","foo/bar"]
  
  # a sample invalid data
  $data = "";
